@@ -197,7 +197,7 @@ ssp_df = ssp_df.fillna(0)
 master_df = data_combined()
 
 # getting the monthly sliced dictionaries
-dict_df, dict_df_future, dict_fy_2022 = data_dict(master_df)
+dict_df, dict_df_future, dict_fy_2022, dict_fy_2023 = data_dict(master_df)
 
 gen_dict = fixing_generalised_logic(dict_df, master_df, ssp_df)
 wacgu_dict = wacgu(gen_dict)
@@ -215,6 +215,8 @@ for i in range(1, 13):
 # main wrapper function
 
 def main_execute():
+    print('Package run 23 executing...')
+
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
                                                                            FY_YEAR[0], month_dict)
@@ -223,11 +225,14 @@ def main_execute():
                                                                            FY_YEAR[1], month_dict)
     base_table_2022, base_table_2022_Inv, base_table_2022_Deal = processor(dict_fy_2022, master_df, ssp_df, wacgu_dict,
                                                                            FY_YEAR[2], month_dict)
+    base_table_2023, base_table_2023_Inv, base_table_2023_Deal = processor(dict_fy_2023, master_df, ssp_df, wacgu_dict,
+                                                                           FY_YEAR[3], month_dict)
 
     # Generate base tables
 
     dashboard_files_new(base_table_2020, base_table_2020_Inv, base_table_2020_Deal, dict_df, FY_YEAR[0])
     dashboard_files_new(base_table_2021, base_table_2021_Inv, base_table_2021_Deal, dict_df_future, FY_YEAR[1])
     dashboard_files_new(base_table_2022, base_table_2022_Inv, base_table_2022_Deal, dict_fy_2022, FY_YEAR[2])
+    dashboard_files_new(base_table_2023, base_table_2023_Inv, base_table_2023_Deal, dict_fy_2023, FY_YEAR[3])
 
     return base_table_2020
