@@ -12,8 +12,8 @@ CONNECTION_STRING = "DefaultEndpointsProtocol=https;AccountName=sttemfinancialre
 STORAGEACCOUNTNAME = "sttemfinancialreporting"
 STORAGEACCOUNTKEY = "ow3mO+jsdSuM7REmLnSupIOyz0mPfwayuy1lt+5UMNykhNgWKfshr6SMV9ttyVxIP9kApKwW716xRaH3GGh8Og=="
 
-def blob_reader(BLOBNAME, LOCALFILENAME):
 
+def blob_reader(BLOBNAME, LOCALFILENAME):
     READ_CONTAINERNAME = "tem-db-tables"
 
     # download from blob
@@ -24,6 +24,7 @@ def blob_reader(BLOBNAME, LOCALFILENAME):
 
     return dataframe_blobdata
 
+
 dataframe_ssp = blob_reader('ssp_table.csv', 'ssp_table.csv')
 dataframe_tradebook = blob_reader('tradebook.csv', 'tradebook.csv')
 
@@ -75,7 +76,7 @@ GEN_LIST = ['GSC-XXX-GS Generalised', 'KACCU-AUS-Generic HIR', 'KACCU-Generic',
             'VCS-IND-Generalised Biomass', 'KACCU-AUS-ALFA Generalised',
             'NZU-NZL-Generalised', 'EUA-EUR-Generic European Allowance', "LGC-AUS-Generic LGC's"]
 
-FY_YEAR = [2020, 2021, 2022]
+FY_YEAR = [2020, 2021, 2022, 2023]
 FY_MAPPER = {'July': 1, 'August': 2, 'September': 3, 'October': 4, 'November': 5, 'December': 6,
              'January': 7, 'February': 8, 'March': 9, 'April': 10, 'May': 11, 'June': 12}
 
